@@ -234,8 +234,9 @@ class PandasGui(QtWidgets.QMainWindow):
         pgdf.dataframe.to_csv(path, index=False)
 
 def show(*args,
-         settings: dict = {},
+         settings={},
          **kwargs):
+
     # Get the variable names in the scope show() was called from
     callers_local_vars = inspect.currentframe().f_back.f_locals.items()
 
